%define apiver 1

Summary: ICONV - Charset Conversion Library
Name: apr-iconv
Version: 1.2.2
Release: 14%{?dist}3a
License: ASL 2.0
URL: https://apr.apache.org/
Source0: https://www.apache.org/dist/apr/%{name}-%{version}.tar.bz2
BuildRequires: apr-devel >= 1.3.0

BuildArch:    fat

%description
This distribution contains the library (libiconv.a and .so) for
conversion between various charsets (character encoding schemes)
and the command line utility (iconv).

Syntax of the library functions (iconv_open, iconv, iconv_close)
and the utility is described in the man pages.

%package devel
Summary: APR iconv library development kit
Requires: apr-iconv%{?_isa} = %{version}-%{release}, apr-devel%{?_isa}, pkgconfig

%description devel
This package provides the support files which can be used to 
build applications using the APR iconv library.  The mission 
of the Apache Portable Runtime (APR) is to provide a free 
library of C data structures and routines.

%prep
%setup -q -c %{name}-%{version}
mv %{name}-%{version} ARM64
cp -a ARM64 X86_64


%build
pushd ARM64
export CC=clang
export CXX=clang++
export CFLAGS="-arch arm64 $RPM_OPT_FLAGS -I%{_includedir}"
export CPPFLAGS="-arch arm64 -I%{_includedir}"
export CXXFLAGS="$CFLAGS"
export LDFLAGS="-arch arm64 $RPM_LD_FLAGS"
export PREFIX="%{_prefix}"
export LIBDIR="%{_libdir}"
./configure --prefix=%{_prefix} --with-apr=%{_prefix} \
        --includedir=%{_includedir}/apr-%{apiver} \
        --disable-static
make %{?_smp_mflags}
popd

pushd X86_64
export CC=clang
export CXX=clang++
export CFLAGS="-arch x86_64 $RPM_OPT_FLAGS -I%{_includedir}"
export CPPFLAGS="-arch x86_64 -I%{_includedir}"
export CXXFLAGS="$CFLAGS"
export LDFLAGS="-arch x86_64 $RPM_LD_FLAGS"
./configure --prefix=%{_prefix} --with-apr=%{_prefix} \
        --includedir=%{_includedir}/apr-%{apiver} \
        --disable-static
(cd build; sed -e 's;arm64;x86_64;g' -i rules.mk)
make %{?_smp_mflags}
popd

%install
rm -rf $RPM_BUILD_ROOT

PWD=`pwd`

pushd ARM64
rm -rf ${PWD}-root
mkdir -p ${PWD}-root
export CFLAGS="-arch arm64 $RPM_OPT_FLAGS -I%{_includedir}"
export CPPFLAGS="-arch arm64 -I%{_includedir}"
export CXXFLAGS="$CFLAGS"
export LDFLAGS="-arch arm64 $RPM_LD_FLAGS"
export PREFIX="%{_prefix}"
export LIBDIR="%{_libdir}"
make install DESTDIR=${PWD}-root
cp -a CHANGES COPYING NOTICE README* LICENSE docs ..
popd

pushd X86_64
rm -rf ${PWD}-root
mkdir -p ${PWD}-root
export CFLAGS="-arch x86_64 $RPM_OPT_FLAGS -I%{_includedir}"
export CPPFLAGS="-arch x86_64 -I%{_includedir}"
export CXXFLAGS="$CFLAGS"
export LDFLAGS="-arch x86_64 $RPM_LD_FLAGS"
make install DESTDIR=${PWD}-root
popd

## Make Universal Binaries
filelist=$(find ./ARM64-root -type f | xargs file | sed -e 's,^\./ARM64-root/,,g' | \
        grep -E \(Mach-O\)\|\(ar\ archive\) |sed -e 's,:.*,,g' -e '/\for\ architecture/d')

for i in $filelist
do
        /usr/bin/lipo -create ARM64-root/$i X86_64-root/$i -output `basename $i` && \
        (cp -f `basename $i` ARM64-root/$i) || :
done

# check header files
for i in `find ARM64-root -name "*.h" -type f`
do
        TARGET=`echo $i | sed -e "s,.*ARM64-root,,"`
        TEMP=`diff -u ARM64-root/$TARGET X86_64-root/$TARGET > /dev/null || echo different`
        if [ -n "$TEMP" ]; then
                mv X86_64-root/$TARGET ARM64-root/${TARGET%.*}-x86_64.h
                mv ARM64-root/$TARGET ARM64-root/${TARGET%.*}-arm64.h
                FILE=${TARGET##*/}
                FILE=${FILE%.*}
cat <<EOF > ARM64-root/$TARGET
#if defined (__arm64__)
#include "${FILE}-arm64.h"
#elif defined( __x86_64__ )
#include "${FILE}-x86_64.h"
#endif
EOF
        fi
done

# remove *.la
find ARM64-root -name '*.la' -exec rm -f {} \;

# install
mkdir -p %{buildroot}
tar cf - -C ARM64-root . | tar xpf - -C %{buildroot}


%clean
rm -rf $RPM_BUILD_ROOT


%files
%defattr(-,root,wheel,-)
%doc CHANGES NOTICE docs
%license LICENSE COPYING
%{_libdir}/libapriconv-%{apiver}.0.dylib
%dir %{_libdir}/iconv
%{_libdir}/iconv/*

%files devel
%defattr(-,root,wheel,-)
%{_bindir}/*
%{_libdir}/libapriconv-%{apiver}.dylib
%{_includedir}/apr-%{apiver}/*.h

%changelog
* Wed Nov 8 2023 Keisuke Fujii <keisuke.fujii@kek.jp> 1.2.2-14hepx3a
- 1st release on MacOS 14 with the latest apr (v.1.7.5)
- built with OSXWS 14 and clang

* Tue Nov 7 2023 Keisuke Fujii <keisuke.fujii@kek.jp> 1.2.2-13hepx2a
- 1st release on MacOS 13
- built with OSXWS 13 and clang

* Thu Jun 9 2022 Keisuke Fujii <keisuke.fujii@kek.jp> 1.2.2-12hepx2a
- 2nd release on MacOS 12 for M1 and Intel Macs (fat).
- built with OSXWS 12beta and clang

* Mon Jun 6 2022 Keisuke Fujii <keisuke.fujii@kek.jp> 1.2.2-12hepx1a
- 1st release on MacOS 12 for M1 Macs.
- built with OSXWS 12beta and clang
